<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is a proprietary licensed product. 
 * For more information see License.txt in the plugin folder.

 * ---
 * Copyright (c) 2019, Ebenezer Obasi
 * All rights reserved.
 * info@eobasi.com.

 * Redistribution and use in source and binary forms, with or without modification, are not permitted provided.

 * This plugin should be bought from the developer. For details contact info@eobasi.com.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Admin Controller
 *
 * @author Ebenezer Obasi <eobasilive@gmail.com, info@eobasi.com>
 * @package ow.plugin.forumpostcontent.controller
 * @since 1.5.3
 */

class FORUMPOSTCONTENT_CTRL_Admin extends ADMIN_CTRL_Abstract
{
    public function index( )
    {
        $this->setPageHeading(OW::getLanguage()->text('forumpostcontent', 'admin_page_heading'));
        $this->assign('contents', FORUMPOSTCONTENT_BOL_Service::getInstance()->findAllContents());
    }

    public function save( )
    {
		$form = new FORUMPOSTCONTENT_CLASS_Form();
		
		if ( OW::getRequest()->isPost() && $form->isValid($_POST) )
		{
            $data = $form->getValues();
			
            $content = new FORUMPOSTCONTENT_BOL_Content();
            
			$content->setTitle(htmlspecialchars($data['title']));
			$content->setContent($data['text']);
			$content->setPosition($data['position']);
			$content->setLayout($data['layout']);
			$content->setOrder($data['order']);
            $content->setTimestamp();
            
            if( isset($data['contentId']) && !empty($contentId = $data['contentId']) )
            {
                $content->setId($contentId);
            }
			
			FORUMPOSTCONTENT_BOL_Service::getInstance()->saveContent($content);
			
			OW::getFeedback()->info(OW::getLanguage()->text('forumpostcontent', 'admin_content_saved'));
            $this->redirectToAction('index');
        }
    }

    public function ajaxDelete()
    {
        $contentId = (int) $_POST['contentId'];

        $response = ['status' => 'fail', 'msg' => ''];

        if( !empty( $content = FORUMPOSTCONTENT_BOL_Service::getInstance()->findContentById($contentId) ) )
        {
            FORUMPOSTCONTENT_BOL_Service::getInstance()->deleteContentById($contentId);

            $response['status'] = 'ok';
        }
        else
        {
            $response['msg'] = OW::getLanguage()->text('forumpostcontent', 'content_not_found');
        }

        exit(json_encode($response));
    }

    public function onBeforeRender()
    {
        parent::onBeforeRender();

        $delUrl = OW::getRouter()->urlFor(__CLASS__, 'ajaxDelete');

        OW::getDocument()->addOnloadScript("$(document).ready(function()
        {
            $('#forumpostcontent-add-content').click(function(){
                var forumPostContentFloatbox = OW.ajaxFloatBox('FORUMPOSTCONTENT_CMP_Form', [], {
                    title: OW.getLanguageText('forumpostcontent', 'add_topic_title'),
                    width: '500px'
                });
            });
            $('.forumpostcontent-edit-link').click(function(){
                var forumPostContent = $(this).closest('.forumpostcontent-item');
                var forumPostContentId = $(forumPostContent).data('id');
                var forumPostContentFloatbox = OW.ajaxFloatBox('FORUMPOSTCONTENT_CMP_Form', [forumPostContentId], {
                    title: OW.getLanguageText('forumpostcontent', 'edit_topic_title'),
                    width: '500px'
                });
            });
            $('.forumpostcontent-edit-delete').click(function()
            {
                if( confirm(OW.getLanguageText('admin', 'are_you_sure')) )
                {
                    var forumPostContent = $(this).closest('.forumpostcontent-item');
                    var forumPostContentId = $(forumPostContent).data('id');
                    $.post('$delUrl',{
                        contentId:forumPostContentId
                    },function(response){
                        response = JSON.parse(response);
                        if( response.status == 'ok')
                        {
                            OW.info(OW.getLanguageText('forumpostcontent', 'content_removed'));
                            $(forumPostContent).remove();
                        }
                        else
                        {
                            OW.error(response.msg);
                        }
                    });
                }

                return false;
            });
        });");

        OW::getLanguage()->addKeyForJs('forumpostcontent', 'add_topic_title');
        OW::getLanguage()->addKeyForJs('forumpostcontent', 'edit_topic_title');
        OW::getLanguage()->addKeyForJs('forumpostcontent', 'content_removed');
        OW::getLanguage()->addKeyForJs('admin', 'are_you_sure');
    }
}